@@ -7,14 +7,16 @@ from tabml.utils.utils import change_working_dir_pytest
 from . import feature_manager, pipelines
 
 
-def _test_inference(config_path):
+def _test_inference(config_path, test_custom_pipeline_config_path=False):
     feature_config_path = "./configs/feature_config.pb"
     last_model_run_dir = ExperimentManger(config_path).get_most_recent_run_dir()
     model_path = Path(last_model_run_dir) / "model_0"
+    pipeline_config_path = config_path if test_custom_pipeline_config_path else None
     model_inference = ModelInference(
         feature_manager_cls=feature_manager.FeatureManager,
         feature_config_path=feature_config_path,
         model_path=model_path,
+        pipeline_config_path=pipeline_config_path,
     )
     raw_data_samples = [
         {
@@ -66,4 +68,6 @@ def test_full_pipeline_xgboost():
 @change_working_dir_pytest
 def test_full_pipeline_catboost():
     pipelines.train_catboost()
-    _test_inference("./configs/catboost_config.pb")
+    _test_inference(
+        "./configs/catboost_config.pb", test_custom_pipeline_config_path=True
+    )
