@@ -2,12 +2,18 @@ from abc import ABC, abstractmethod
 from typing import Any, Dict, Iterable, Union
 
 import mlflow
+from catboost import CatBoostClassifier, CatBoostRegressor
 from lightgbm import LGBMClassifier, LGBMRegressor
+from xgboost import XGBClassifier, XGBRegressor
 
 from tabml.utils import utils
 from tabml.utils.pb_helpers import pb_to_dict
 
-MLFLOW_AUTOLOG = {"lightgbm": mlflow.lightgbm.autolog()}
+MLFLOW_AUTOLOG = {
+    "lightgbm": mlflow.lightgbm.autolog(),
+    "xgboost": mlflow.xgboost.autolog(),
+    "catboost": None,
+}
 
 
 class BaseModelWrapper(ABC):
@@ -16,21 +22,18 @@ class BaseModelWrapper(ABC):
     def __init__(self, config):
         self.config = config
         self.model = None
-        self._feature_names = None
+        self.feature_names = list(self.config.data_loader.features_to_model)
         self.params: Union[Dict[str, Any], None] = None
 
     @abstractmethod
     def predict(self, data) -> Iterable:
-        """Predicts data inputs.
-
-        data should be the remaining part of dataset without the label column.
-        """
+        """Predicts data inputs."""
         raise NotImplementedError
 
     def predict_proba(self, data) -> Iterable:
         """Predicts probability of data inputs.
 
-        Only appropriate with binary classification problems, the second value in
+        Only applied to binary classification problems, the second value in
         probability (prob of positive) is chosen.
         """
         raise NotImplementedError
@@ -39,25 +42,6 @@ class BaseModelWrapper(ABC):
     def load_model(self, model_path: str):
         raise NotImplementedError
 
-    @abstractmethod
-    def show_feature_importance(self, importance_type: str = "gain") -> None:
-        """Displays feature importance after training."""
-
-    @property
-    def feature_names(self):
-        assert (
-            self._feature_names is not None
-        ), "self._feature_names has not been set. Please set it first."
-        return self._feature_names
-
-    @feature_names.setter
-    def feature_names(self, names):
-        """Sets feature names during training. This should be set only once."""
-        assert (
-            self._feature_names is None
-        ), f"feature_names has been set before, feature_names = {self.feature_names}"
-        self._feature_names = names
-
 
 class BaseLgbmModelWrapper(BaseModelWrapper):
     mlflow_model_type = "lightgbm"
@@ -77,17 +61,6 @@ class BaseLgbmModelWrapper(BaseModelWrapper):
     def load_model(self, model_path: str):
         self.model = utils.load_pickle(model_path)
 
-    def show_feature_importance(self, importance_type: str = "gain") -> None:
-        importances = self.model.booster_.feature_importance(
-            importance_type=importance_type
-        )
-        assert len(self.feature_names) == len(importances), (
-            "feature_names and importances have different lengths "
-            f"({len(self.feature_names)} != {len(importances)})"
-        )
-        data = {self.feature_names[i]: importances[i] for i in range(len(importances))}
-        utils.show_feature_importance(data)
-
 
 class LgbmClassifierModelWrapper(BaseLgbmModelWrapper):
     def build_model(self):
@@ -100,3 +73,69 @@ class LgbmClassifierModelWrapper(BaseLgbmModelWrapper):
 class LgbmRegressorModelWrapper(BaseLgbmModelWrapper):
     def build_model(self):
         return LGBMRegressor(**self.params)
+
+
+class BaseXGBoostModelWrapper(BaseModelWrapper):
+    mlflow_model_type = "xgboost"
+
+    def __init__(self, config):
+        super(BaseXGBoostModelWrapper, self).__init__(config)
+        self.params = pb_to_dict(self.config.model_wrapper.xgboost_params)
+        self.tree_method = "gpu_hist" if utils.is_gpu_available() else "auto"
+        self.model = self.build_model()
+
+    @abstractmethod
+    def build_model(self):
+        pass
+
+    def predict(self, data):
+        return self.model.predict(data)
+
+    def load_model(self, model_path: str):
+        self.model = utils.load_pickle(model_path)
+
+
+class XGBoostRegressorModelWrapper(BaseXGBoostModelWrapper):
+    def build_model(self):
+        return XGBRegressor(tree_method=self.tree_method, **self.params)
+
+
+class XGBoostClassifierModelWrapper(BaseXGBoostModelWrapper):
+    def build_model(self):
+        return XGBClassifier(tree_method=self.tree_method, **self.params)
+
+    def predict_proba(self, data) -> Iterable:
+        return self.model.predict_proba(data)[:, 1]
+
+
+class BaseCatBoostModelWrapper(BaseModelWrapper):
+    mlflow_model_type = "catboost"
+
+    def __init__(self, config):
+        super(BaseCatBoostModelWrapper, self).__init__(config)
+        self.params = pb_to_dict(self.config.model_wrapper.catboost_params)
+        self.task_type = "GPU" if utils.is_gpu_available() else "CPU"
+        self.model = self.build_model()
+
+    @abstractmethod
+    def build_model(self):
+        pass
+
+    def predict(self, data):
+        return self.model.predict(data)
+
+    def load_model(self, model_path: str):
+        self.model = utils.load_pickle(model_path)
+
+
+class CatBoostClassifierModelWrapper(BaseCatBoostModelWrapper):
+    def build_model(self):
+        return CatBoostClassifier(**self.params)
+
+    def predict_proba(self, data) -> Iterable:
+        return self.model.predict_proba(data)[:, 1]
+
+
+class CatBoostRegressorModelWrapper(BaseCatBoostModelWrapper):
+    def build_model(self):
+        return CatBoostRegressor(task_type=self.task_type, **self.params)
