@@ -48,8 +48,10 @@ class BasePipeline(ABC):
     def run(self):
         self.exp_manager.create_new_run_dir()
         # start mlflow auto log
-        model_wrappers.MLFLOW_AUTOLOG[self.model_wrapper.mlflow_model_type]
+        model_type = self.model_wrapper.mlflow_model_type
+        model_wrappers.MLFLOW_AUTOLOG[model_type]
         with mlflow.start_run():
+            mlflow.log_param("model_type", model_type)
             mlflow.log_params(self.model_wrapper.params)
             self.train()
             self.analyze_model()
@@ -90,6 +92,12 @@ class BasePipeline(ABC):
             "At least one by_features in model_analysis must be specified. "
             "Add the by_features in model_analysis in the pipeline config"
         )
+
+        # In protocol buffer, default value for int32 is 0.
+        if self.config.model_analysis.training_size == 0:
+            training_size = None
+        else:
+            training_size = self.config.model_analysis.training_size
         ModelAnalysis(
             data_loader=self.data_loader,
             model_wrapper=self.model_wrapper,
@@ -97,4 +105,5 @@ class BasePipeline(ABC):
             label_to_analyze=self.config.model_analysis.by_label,
             metric_names=self.config.model_analysis.metrics,
             output_dir=self.exp_manager.get_model_analysis_dir(),
+            training_size=training_size,
         ).analyze()
